@@ -91,7 +91,8 @@ class PFSMixin:
         * `update`: Whether to update if the repo already exists.
         """
         return self._req(
-            Service.PFS, "CreateRepo",
+            Service.PFS,
+            "CreateRepo",
             repo=pfs_proto.Repo(name=repo_name),
             description=description,
             update=update,
@@ -105,7 +106,9 @@ class PFSMixin:
 
         * `repo_name`: Name of the repo.
         """
-        return self._req(Service.PFS, "InspectRepo", repo=pfs_proto.Repo(name=repo_name))
+        return self._req(
+            Service.PFS, "InspectRepo", repo=pfs_proto.Repo(name=repo_name)
+        )
 
     def list_repo(self):
         """
@@ -127,9 +130,14 @@ class PFSMixin:
           Setting this to `True` can work around certain Pachyderm errors, but,
           if set, the `delete_repo` call may need to be retried.
         """
-        return self._req(Service.PFS, "DeleteRepo",
-                         repo=pfs_proto.Repo(name=repo_name), force=force,
-                         all=False, split_transaction=split_transaction)
+        return self._req(
+            Service.PFS,
+            "DeleteRepo",
+            repo=pfs_proto.Repo(name=repo_name),
+            force=force,
+            all=False,
+            split_transaction=split_transaction,
+        )
 
     def delete_all_repos(self, force=None):
         """
@@ -142,7 +150,9 @@ class PFSMixin:
         """
         return self._req(Service.PFS, "DeleteRepo", force=force, all=True)
 
-    def start_commit(self, repo_name, branch=None, parent=None, description=None, provenance=None):
+    def start_commit(
+        self, repo_name, branch=None, parent=None, description=None, provenance=None
+    ):
         """
         Begins the process of committing data to a Repo. Once started you can
         write to the Commit with PutFile and when all the data has been
@@ -168,15 +178,24 @@ class PFSMixin:
         specifying the commit provenance.
         """
         return self._req(
-            Service.PFS, "StartCommit",
+            Service.PFS,
+            "StartCommit",
             parent=pfs_proto.Commit(repo=pfs_proto.Repo(name=repo_name), id=parent),
             branch=branch,
             description=description,
             provenance=provenance,
         )
 
-    def finish_commit(self, commit, description=None, input_tree_object_hash=None, tree_object_hashes=None,
-                      datum_object_hash=None, size_bytes=None, empty=None):
+    def finish_commit(
+        self,
+        commit,
+        description=None,
+        input_tree_object_hash=None,
+        tree_object_hashes=None,
+        datum_object_hash=None,
+        size_bytes=None,
+        empty=None,
+    ):
         """
         Ends the process of committing data to a Repo and persists the
         Commit. Once a Commit is finished the data becomes immutable and
@@ -198,12 +217,19 @@ class PFSMixin:
         be left nil.
         """
         return self._req(
-            Service.PFS, "FinishCommit",
+            Service.PFS,
+            "FinishCommit",
             commit=commit_from(commit),
             description=description,
-            tree=pfs_proto.Object(hash=input_tree_object_hash) if input_tree_object_hash is not None else None,
-            trees=[pfs_proto.Object(hash=h) for h in tree_object_hashes] if tree_object_hashes is not None else None,
-            datums=pfs_proto.Object(hash=datum_object_hash) if datum_object_hash is not None else None,
+            tree=pfs_proto.Object(hash=input_tree_object_hash)
+            if input_tree_object_hash is not None
+            else None,
+            trees=[pfs_proto.Object(hash=h) for h in tree_object_hashes]
+            if tree_object_hashes is not None
+            else None,
+            datums=pfs_proto.Object(hash=datum_object_hash)
+            if datum_object_hash is not None
+            else None,
             size_bytes=size_bytes,
             empty=empty,
         )
@@ -245,9 +271,16 @@ class PFSMixin:
         * An optional int that causes this method to block until the commit is
         in the desired commit state. See the `CommitState` enum.
         """
-        return self._req(Service.PFS, "InspectCommit", commit=commit_from(commit), block_state=block_state)
+        return self._req(
+            Service.PFS,
+            "InspectCommit",
+            commit=commit_from(commit),
+            block_state=block_state,
+        )
 
-    def list_commit(self, repo_name, to_commit=None, from_commit=None, number=None, reverse=None):
+    def list_commit(
+        self, repo_name, to_commit=None, from_commit=None, number=None, reverse=None
+    ):
         """
         Lists commits. Yields `CommitInfo` objects.
 
@@ -263,11 +296,13 @@ class PFSMixin:
         `number` is 0, all commits that match the aforementioned criteria are
         returned.
         """
-        req = pfs_proto.ListCommitRequest(repo=pfs_proto.Repo(name=repo_name), number=number, reverse=reverse)
+        req = pfs_proto.ListCommitRequest(
+            repo=pfs_proto.Repo(name=repo_name), number=number, reverse=reverse
+        )
         if to_commit is not None:
             req.to.CopyFrom(commit_from(to_commit))
         if from_commit is not None:
-            getattr(req, 'from').CopyFrom(commit_from(from_commit))
+            getattr(req, "from").CopyFrom(commit_from(from_commit))
         return self._req(Service.PFS, "ListCommitStream", req=req)
 
     def delete_commit(self, commit):
@@ -304,12 +339,17 @@ class PFSMixin:
         specified, only commits within these repos will be flushed.
         """
         return self._req(
-            Service.PFS, "FlushCommit",
+            Service.PFS,
+            "FlushCommit",
             commits=[commit_from(c) for c in commits],
-            to_repos=[pfs_proto.Repo(name=r) for r in repos] if repos is not None else None,
+            to_repos=[pfs_proto.Repo(name=r) for r in repos]
+            if repos is not None
+            else None,
         )
 
-    def subscribe_commit(self, repo_name, branch, from_commit_id=None, state=None, prov=None):
+    def subscribe_commit(
+        self, repo_name, branch, from_commit_id=None, state=None, prov=None
+    ):
         """
         Yields `CommitInfo` objects as commits occur.
 
@@ -323,13 +363,18 @@ class PFSMixin:
         * `prov`: An optional `CommitProvenance` object.
         """
         repo = pfs_proto.Repo(name=repo_name)
-        req = pfs_proto.SubscribeCommitRequest(repo=repo, branch=branch, state=state, prov=prov)
+        req = pfs_proto.SubscribeCommitRequest(
+            repo=repo, branch=branch, state=state, prov=prov
+        )
         if from_commit_id is not None:
-            getattr(req, 'from').CopyFrom(pfs_proto.Commit(repo=repo, id=from_commit_id))
+            getattr(req, "from").CopyFrom(
+                pfs_proto.Commit(repo=repo, id=from_commit_id)
+            )
         return self._req(Service.PFS, "SubscribeCommit", req=req)
 
-    def create_branch(self, repo_name, branch_name, commit=None,
-                      provenance=None, trigger=None):
+    def create_branch(
+        self, repo_name, branch_name, commit=None, provenance=None, trigger=None
+    ):
         """
         Creates a new branch.
 
@@ -345,10 +390,14 @@ class PFSMixin:
           `branch_name` is moved.
         """
         return self._req(
-            Service.PFS, "CreateBranch",
-            branch=pfs_proto.Branch(repo=pfs_proto.Repo(name=repo_name), name=branch_name),
+            Service.PFS,
+            "CreateBranch",
+            branch=pfs_proto.Branch(
+                repo=pfs_proto.Repo(name=repo_name), name=branch_name
+            ),
             head=commit_from(commit) if commit is not None else None,
-            provenance=provenance, trigger=trigger,
+            provenance=provenance,
+            trigger=trigger,
         )
 
     def inspect_branch(self, repo_name, branch_name):
@@ -356,8 +405,11 @@ class PFSMixin:
         Inspects a branch. Returns a `BranchInfo` object.
         """
         return self._req(
-            Service.PFS, "InspectBranch",
-            branch=pfs_proto.Branch(repo=pfs_proto.Repo(name=repo_name), name=branch_name),
+            Service.PFS,
+            "InspectBranch",
+            branch=pfs_proto.Branch(
+                repo=pfs_proto.Repo(name=repo_name), name=branch_name
+            ),
         )
 
     def list_branch(self, repo_name, reverse=None):
@@ -369,7 +421,12 @@ class PFSMixin:
 
         * `repo_name`: A string specifying the repo name.
         """
-        return self._req(Service.PFS, "ListBranch", repo=pfs_proto.Repo(name=repo_name), reverse=reverse).branch_info
+        return self._req(
+            Service.PFS,
+            "ListBranch",
+            repo=pfs_proto.Repo(name=repo_name),
+            reverse=reverse,
+        ).branch_info
 
     def delete_branch(self, repo_name, branch_name, force=None):
         """
@@ -384,8 +441,11 @@ class PFSMixin:
         * `force`: A bool specifying whether to force the branch deletion.
         """
         return self._req(
-            Service.PFS, "DeleteBranch",
-            branch=pfs_proto.Branch(repo=pfs_proto.Repo(name=repo_name), name=branch_name),
+            Service.PFS,
+            "DeleteBranch",
+            branch=pfs_proto.Branch(
+                repo=pfs_proto.Repo(name=repo_name), name=branch_name
+            ),
             force=force,
         )
 
@@ -400,8 +460,17 @@ class PFSMixin:
         yield pfc
         self._req(Service.PFS, "PutFile", req=pfc._reqs())
 
-    def put_file_bytes(self, commit, path, value, delimiter=None, target_file_datums=None,
-                       target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_bytes(
+        self,
+        commit,
+        path,
+        value,
+        delimiter=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Uploads a PFS file from a file-like object, bytestring, or iterator
         of bytestrings.
@@ -431,7 +500,9 @@ class PFSMixin:
         is not `NONE` (or `SQL`). It specifies the number of records that are
         converted to a header and applied to all file shards.
         """
-        if isinstance(value, collections.abc.Iterable) and not isinstance(value, (str, bytes)):
+        if isinstance(value, collections.abc.Iterable) and not isinstance(
+            value, (str, bytes)
+        ):
             warnings.warn(
                 "'put_file_bytes' with an iterable 'value' is deprecated, use file-like objects or bytestrings instead",
                 DeprecationWarning,
@@ -450,7 +521,9 @@ class PFSMixin:
         with self.put_file_client() as pfc:
             if hasattr(value, "read"):
                 return pfc.put_file_from_fileobj(
-                    commit, path, value,
+                    commit,
+                    path,
+                    value,
                     delimiter=delimiter,
                     target_file_datums=target_file_datums,
                     target_file_bytes=target_file_bytes,
@@ -459,7 +532,9 @@ class PFSMixin:
                 )
             else:
                 return pfc.put_file_from_bytes(
-                    commit, path, value,
+                    commit,
+                    path,
+                    value,
                     delimiter=delimiter,
                     target_file_datums=target_file_datums,
                     target_file_bytes=target_file_bytes,
@@ -467,8 +542,18 @@ class PFSMixin:
                     header_records=header_records,
                 )
 
-    def put_file_url(self, commit, path, url, delimiter=None, recursive=None, target_file_datums=None,
-                     target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_url(
+        self,
+        commit,
+        path,
+        url,
+        delimiter=None,
+        recursive=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Puts a file using the content found at a URL. The URL is sent to the
         server which performs the request.
@@ -501,7 +586,9 @@ class PFSMixin:
 
         with self.put_file_client() as pfc:
             pfc.put_file_from_url(
-                commit, path, url,
+                commit,
+                path,
+                url,
                 delimiter=delimiter,
                 recursive=recursive,
                 target_file_datums=target_file_datums,
@@ -510,7 +597,9 @@ class PFSMixin:
                 header_records=header_records,
             )
 
-    def copy_file(self, source_commit, source_path, dest_commit, dest_path, overwrite=None):
+    def copy_file(
+        self, source_commit, source_path, dest_commit, dest_path, overwrite=None
+    ):
         """
         Efficiently copies files already in PFS. Note that the destination
         repo cannot be an output repo, or the copy operation will (as of
@@ -528,7 +617,8 @@ class PFSMixin:
         destination file if it already exists.
         """
         return self._req(
-            Service.PFS, "CopyFile",
+            Service.PFS,
+            "CopyFile",
             src=pfs_proto.File(commit=commit_from(source_commit), path=source_path),
             dst=pfs_proto.File(commit=commit_from(dest_commit), path=dest_path),
             overwrite=overwrite,
@@ -552,7 +642,8 @@ class PFSMixin:
         data will be returned.
         """
         res = self._req(
-            Service.PFS, "GetFile",
+            Service.PFS,
+            "GetFile",
             file=pfs_proto.File(commit=commit_from(commit), path=path),
             offset_bytes=offset_bytes,
             size_bytes=size_bytes,
@@ -569,7 +660,11 @@ class PFSMixin:
         commit.
         * `path`: A string specifying the path to the file.
         """
-        return self._req(Service.PFS, "InspectFile", file=pfs_proto.File(commit=commit_from(commit), path=path))
+        return self._req(
+            Service.PFS,
+            "InspectFile",
+            file=pfs_proto.File(commit=commit_from(commit), path=path),
+        )
 
     def list_file(self, commit, path, history=None, include_contents=None):
         """
@@ -590,7 +685,8 @@ class PFSMixin:
         included.
         """
         return self._req(
-            Service.PFS, "ListFileStream",
+            Service.PFS,
+            "ListFileStream",
             file=pfs_proto.File(commit=commit_from(commit), path=path),
             history=history,
             full=include_contents,
@@ -607,7 +703,11 @@ class PFSMixin:
         commit.
         * `path`: The path to the directory.
         """
-        return self._req(Service.PFS, "WalkFile", file=pfs_proto.File(commit=commit_from(commit), path=path))
+        return self._req(
+            Service.PFS,
+            "WalkFile",
+            file=pfs_proto.File(commit=commit_from(commit), path=path),
+        )
 
     def glob_file(self, commit, pattern):
         """
@@ -619,7 +719,9 @@ class PFSMixin:
         commit.
         * `pattern`: A string representing a glob pattern.
         """
-        return self._req(Service.PFS, "GlobFileStream", commit=commit_from(commit), pattern=pattern)
+        return self._req(
+            Service.PFS, "GlobFileStream", commit=commit_from(commit), pattern=pattern
+        )
 
     def delete_file(self, commit, path):
         """
@@ -634,7 +736,11 @@ class PFSMixin:
         commit.
         * `path`: The path to the file.
         """
-        return self._req(Service.PFS, "DeleteFile", file=pfs_proto.File(commit=commit_from(commit), path=path))
+        return self._req(
+            Service.PFS,
+            "DeleteFile",
+            file=pfs_proto.File(commit=commit_from(commit), path=path),
+        )
 
     def fsck(self, fix=None):
         """
@@ -642,7 +748,9 @@ class PFSMixin:
         """
         return self._req(Service.PFS, "Fsck", fix=fix)
 
-    def diff_file(self, new_commit, new_path, old_commit=None, old_path=None, shallow=None):
+    def diff_file(
+        self, new_commit, new_path, old_commit=None, old_path=None, shallow=None
+    ):
         """
         Diffs two files. If `old_commit` or `old_path` are not specified, the
         same path in the parent of the file specified by `new_commit` and
@@ -665,7 +773,8 @@ class PFSMixin:
             old_file = None
 
         return self._req(
-            Service.PFS, "DiffFile",
+            Service.PFS,
+            "DiffFile",
             new_file=pfs_proto.File(commit=commit_from(new_commit), path=new_path),
             old_file=old_file,
             shallow=shallow,
@@ -683,7 +792,7 @@ class PFSMixin:
 
         * `fileset_id`: A string identifying the fileset.
         """
-        raise NotImplementedError('temporary filesets are internal-use-only')
+        raise NotImplementedError("temporary filesets are internal-use-only")
 
     def renew_tmp_file_set(self, fileset_id, ttl_seconds):
         """
@@ -699,7 +808,7 @@ class PFSMixin:
         * `ttl_seconds`: A int determining the number of seconds to keep alive
         the temporary fileset
         """
-        raise NotImplementedError('temporary filesets are internal-use-only')
+        raise NotImplementedError("temporary filesets are internal-use-only")
 
 
 class PutFileClient:
@@ -714,8 +823,17 @@ class PutFileClient:
         for op in self._ops:
             yield from op.reqs()
 
-    def put_file_from_filepath(self, commit, pfs_path, local_path, delimiter=None, target_file_datums=None,
-                               target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_from_filepath(
+        self,
+        commit,
+        pfs_path,
+        local_path,
+        delimiter=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Uploads a PFS file from a local path at a specified path. This will
         lazily open files, which will prevent too many files from being
@@ -746,17 +864,32 @@ class PutFileClient:
         is not `NONE` (or `SQL`). It specifies the number of records that are
         converted to a header and applied to all file shards.
         """
-        self._ops.append(AtomicPutFilepathOp(
-            commit, pfs_path, local_path,
-            delimiter=delimiter,
-            target_file_datums=target_file_datums,
-            target_file_bytes=target_file_bytes,
-            overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index) if overwrite_index is not None else None,
-            header_records=header_records,
-        ))
+        self._ops.append(
+            AtomicPutFilepathOp(
+                commit,
+                pfs_path,
+                local_path,
+                delimiter=delimiter,
+                target_file_datums=target_file_datums,
+                target_file_bytes=target_file_bytes,
+                overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index)
+                if overwrite_index is not None
+                else None,
+                header_records=header_records,
+            )
+        )
 
-    def put_file_from_fileobj(self, commit, path, value, delimiter=None, target_file_datums=None,
-                              target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_from_fileobj(
+        self,
+        commit,
+        path,
+        value,
+        delimiter=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Uploads a PFS file from a file-like object.
 
@@ -784,17 +917,32 @@ class PutFileClient:
         is not `NONE` (or `SQL`). It specifies the number of records that are
         converted to a header and applied to all file shards.
         """
-        self._ops.append(AtomicPutFileobjOp(
-            commit, path, value,
-            delimiter=delimiter,
-            target_file_datums=target_file_datums,
-            target_file_bytes=target_file_bytes,
-            overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index) if overwrite_index is not None else None,
-            header_records=header_records,
-        ))
+        self._ops.append(
+            AtomicPutFileobjOp(
+                commit,
+                path,
+                value,
+                delimiter=delimiter,
+                target_file_datums=target_file_datums,
+                target_file_bytes=target_file_bytes,
+                overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index)
+                if overwrite_index is not None
+                else None,
+                header_records=header_records,
+            )
+        )
 
-    def put_file_from_bytes(self, commit, path, value, delimiter=None, target_file_datums=None,
-                            target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_from_bytes(
+        self,
+        commit,
+        path,
+        value,
+        delimiter=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Uploads a PFS file from a bytestring.
 
@@ -823,7 +971,9 @@ class PutFileClient:
         converted to a header and applied to all file shards.
         """
         self.put_file_from_fileobj(
-            commit, path, io.BytesIO(value),
+            commit,
+            path,
+            io.BytesIO(value),
             delimiter=delimiter,
             target_file_datums=target_file_datums,
             target_file_bytes=target_file_bytes,
@@ -831,8 +981,18 @@ class PutFileClient:
             header_records=header_records,
         )
 
-    def put_file_from_url(self, commit, path, url, delimiter=None, recursive=None, target_file_datums=None,
-                          target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_from_url(
+        self,
+        commit,
+        path,
+        url,
+        delimiter=None,
+        recursive=None,
+        target_file_datums=None,
+        target_file_bytes=None,
+        overwrite_index=None,
+        header_records=None,
+    ):
         """
         Puts a file using the content found at a URL. The URL is sent to the
         server which performs the request.
@@ -862,16 +1022,21 @@ class PutFileClient:
         is not `NONE` (or `SQL`). It specifies the number of records that are
         converted to a header and applied to all file shards.
         """
-        self._ops.append(AtomicOp(
-            commit, path,
-            url=url,
-            delimiter=delimiter,
-            recursive=recursive,
-            target_file_datums=target_file_datums,
-            target_file_bytes=target_file_bytes,
-            overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index) if overwrite_index is not None else None,
-            header_records=header_records,
-        ))
+        self._ops.append(
+            AtomicOp(
+                commit,
+                path,
+                url=url,
+                delimiter=delimiter,
+                recursive=recursive,
+                target_file_datums=target_file_datums,
+                target_file_bytes=target_file_bytes,
+                overwrite_index=pfs_proto.OverwriteIndex(index=overwrite_index)
+                if overwrite_index is not None
+                else None,
+                header_records=header_records,
+            )
+        )
 
     def delete_file(self, commit, path):
         """
@@ -930,22 +1095,16 @@ class AtomicPutFileobjOp(AtomicOp):
         yield from put_file_from_fileobj_reqs(self.value, **self.kwargs)
 
 
-def put_file_from_fileobj_reqs(value, **kwargs):
-    for i in itertools.count():
-        chunk = value.read(BUFFER_SIZE)
-
-        if len(chunk) == 0:
-            return
-
-        if i == 0:
-            yield pfs_proto.PutFileRequest(value=chunk, **kwargs)
-        else:
-            yield pfs_proto.PutFileRequest(value=chunk)
+def put_file_from_fileobj_reqs(fileish, **kwargs):
+    chunked_iter = itertools.takewhile(
+        lambda chunk: len(chunk) > 0, map(fileish.read, itertools.repeat(BUFFER_SIZE))
+    )
+    return put_file_from_iterable_reqs(chunked_iter, **kwargs)
 
 
 def put_file_from_iterable_reqs(value, **kwargs):
-    for i, chunk in enumerate(value):
+    for i, chunk in enumerate(itertools.chain(value, [None])):
         if i == 0:
             yield pfs_proto.PutFileRequest(value=chunk, **kwargs)
-        else:
+        elif chunk is not None:
             yield pfs_proto.PutFileRequest(value=chunk)
