@@ -17,7 +17,9 @@ def test_extract_restore():
 @util.skip_if_below_pachyderm_version(1, 8, 8)
 def test_extract_pipeline_restore():
     client = python_pachyderm.Client()
-    _, _, pipeline_name = util.create_test_pipeline(client, "test_extract_pipeline_restore")
+    _, _, pipeline_name = util.create_test_pipeline(
+        client, "test_extract_pipeline_restore"
+    )
     op = client.extract_pipeline(pipeline_name)
     client.restore((python_pachyderm.RestoreRequest(op=op) for op in (op,)))
 
